@@ -331,17 +331,17 @@ if (get_nfilter_request_var('action') == 'login') {
 				 * have console access
 				 */
 				if (isset($_SERVER['REDIRECT_URL'])) {
-					$referer = $_SERVER['REDIRECT_URL'];
+					$referer = sanitize_uri($_SERVER['REDIRECT_URL']);
 					if (isset($_SERVER['REDIRECT_QUERY_STRING'])) {
 						$referer .= '?' . $_SERVER['REDIRECT_QUERY_STRING'] . ($newtheme ? '&newtheme=1':'');
 					}
-				} else if (isset($_SERVER['HTTP_REFERER'])) {
-					$referer = $_SERVER['HTTP_REFERER'];
+				} elseif (isset($_SERVER['HTTP_REFERER'])) {
+					$referer = sanitize_uri($_SERVER['HTTP_REFERER']);
 					if (basename($referer) == 'logout.php') {
 						$referer = $config['url_path'] . 'index.php' . ($newtheme ? '?newtheme=1':'');
 					}
-				} else if (isset($_SERVER['REQUEST_URI'])) {
-					$referer = $_SERVER['REQUEST_URI'];
+				} elseif (isset($_SERVER['REQUEST_URI'])) {
+					$referer = sanitize_uri($_SERVER['REQUEST_URI']);
 					if (basename($referer) == 'logout.php') {
 						$referer = $config['url_path'] . 'index.php' . ($newtheme ? '?newtheme=1':'');
 					}
@@ -351,7 +351,7 @@ if (get_nfilter_request_var('action') == 'login') {
 
 				if (substr_count($referer, 'plugins')) {
 					header('Location: ' . $referer);
-				} elseif (sizeof(db_fetch_assoc_prepared('SELECT realm_id FROM user_auth_realm WHERE realm_id = 8 AND user_id = ?', array($_SESSION['sess_user_id']))) == 0) {
+				} elseif (!is_realm_allowed(8)) {
 					header('Location: graph_view.php' . ($newtheme ? '?newtheme=1':''));
 				} else {
 					$param_char = '?';
@@ -383,7 +383,10 @@ if (get_nfilter_request_var('action') == 'login') {
 			exit;
 		} else {
 			/* BAD username/password builtin and LDAP */
-			db_execute_prepared('INSERT IGNORE INTO user_log (username, user_id, result, ip, time) VALUES (?, 0, 0, ?, NOW())', array($username, $_SERVER['REMOTE_ADDR']));
+			db_execute_prepared('INSERT IGNORE INTO user_log
+				(username, user_id, result, ip, time)
+				VALUES (?, 0, 0, ?, NOW())',
+				array($username, $_SERVER['REMOTE_ADDR']));
 		}
 	}
 }
@@ -434,24 +437,48 @@ function domains_login_process() {
 
 			if ($ldap_auth_response['error_num'] == '0') {
 				/* User ok */
-				$user_auth = true;
-				$copy_user = true;
-				$realm = get_nfilter_request_var('realm');
+				$user_auth   = true;
+				$copy_user   = true;
+				$realm       = get_nfilter_request_var('realm');
+
+				$domain_name = db_fetch_cell_prepared('SELECT domain_name
+					FROM user_domains
+					WHERE domain_id = ?',
+					array($realm-1000));
+
 				/* Locate user in database */
-				cacti_log("LOGIN: LDAP User '" . $username . "' Authenticated from Domain '" . db_fetch_cell('SELECT domain_name FROM user_domains WHERE domain_id=' . ($realm-1000)) . "'", false, 'AUTH');
-				$user = db_fetch_row_prepared('SELECT * FROM user_auth WHERE username = ? AND realm = ?', array($username, $realm));
+				cacti_log("LOGIN: LDAP User '$username' Authenticated from Domain '$domain_name'", false, 'AUTH');
+
+				$user = db_fetch_row_prepared('SELECT *
+					FROM user_auth
+					WHERE username = ?
+					AND realm = ?',
+					array($username, $realm));
 
 				/* Create user from template if requested */
-				$template_user = db_fetch_cell_prepared('SELECT user_id FROM user_domains WHERE domain_id = ?', array(get_nfilter_request_var('realm')-1000));
-				$template_username = db_fetch_cell_prepared('SELECT username FROM user_auth WHERE id = ?', array($template_user));
-				if (!sizeof($user) && $copy_user && $template_user != '0' && $username != '') {
+				$template_user = db_fetch_cell_prepared('SELECT user_id
+					FROM user_domains
+					WHERE domain_id = ?',
+					array(get_nfilter_request_var('realm')-1000));
+
+				$template_username = db_fetch_cell_prepared('SELECT username
+					FROM user_auth
+					WHERE id = ?',
+					array($template_user));
+
+				if (!sizeof($user) && $copy_user && !empty($template_user) && $username != '') {
 					cacti_log("WARN: User '" . $username . "' does not exist, copying template user", false, 'AUTH');
 					/* check that template user exists */
 					if (db_fetch_row_prepared('SELECT id FROM user_auth WHERE id = ? AND realm = 0', array($template_user))) {
 						/* template user found */
 						user_copy($template_username, $username, 0, $realm);
+
 						/* requery newly created user */
-						$user = db_fetch_row_prepared('SELECT * FROM user_auth WHERE username = ? AND realm = ?', array($username, $realm));
+						$user = db_fetch_row_prepared('SELECT *
+							FROM user_auth
+							WHERE username = ?
+							AND realm = ?',
+							array($username, $realm));
 					} else {
 						/* error */
 						display_custom_error_message(__('Template user %s does not exist.', $template_username));
@@ -479,7 +506,10 @@ function domains_ldap_auth($username, $password = '', $dn = '', $realm) {
 	if (!empty($password)) $ldap->password = $password;
 	if (!empty($dn))       $ldap->dn       = $dn;
 
-	$ld = db_fetch_row_prepared('SELECT * FROM user_domains_ldap WHERE domain_id = ?', array($realm-1000));
+	$ld = db_fetch_row_prepared('SELECT *
+		FROM user_domains_ldap
+		WHERE domain_id = ?',
+		array($realm-1000));
 
 	if (sizeof($ld)) {
 		if (!empty($ld['dn']))                $ldap->dn                = $ld['dn'];
@@ -498,7 +528,7 @@ function domains_ldap_auth($username, $password = '', $dn = '', $realm) {
 
 		if ($ld['group_require'] == 'on') {
 			$ldap->group_require = true;
-		}else{
+		} else {
 			$ldap->group_require = false;
 		}
 		if (!empty($ld['group_dn']))          $ldap->group_dn          = $ld['group_dn'];
@@ -516,7 +546,10 @@ function domains_ldap_search_dn($username, $realm) {
 
 	if (!empty($username)) $ldap->username = $username;
 
-	$ld = db_fetch_row_prepared('SELECT * FROM user_domains_ldap WHERE domain_id = ?', array($realm-1000));
+	$ld = db_fetch_row_prepared('SELECT *
+		FROM user_domains_ldap
+		WHERE domain_id = ?',
+		array($realm-1000));
 
 	if (sizeof($ld)) {
 		if (!empty($ld['dn']))                $ldap->dn                = $ld['dn'];
@@ -535,9 +568,10 @@ function domains_ldap_search_dn($username, $realm) {
 
 		if ($ld['group_require'] == 'on') {
 			$ldap->group_require = true;
-		}else{
+		} else {
 			$ldap->group_require = false;
 		}
+
 		if (!empty($ld['group_dn']))          $ldap->group_dn          = $ld['group_dn'];
 		if (!empty($ld['group_attrib']))      $ldap->group_attrib      = $ld['group_attrib'];
 		if (!empty($ld['group_member_type'])) $ldap->group_member_type = $ld['group_member_type'];
@@ -628,7 +662,7 @@ $selectedTheme = get_selected_theme();
 							<td>
 								<select id='realm' name='realm'><?php
 									if (sizeof($realms)) {
-										foreach($realms as $index => $realm) {
+										foreach ($realms as $index => $realm) {
 											print "\t\t\t\t\t<option value='" . $index . "'" . ($realm['selected'] ? ' selected':'') . '>' . htmlspecialchars($realm['name']) . "</option>\n";
 										}
 									}
