@@ -573,7 +573,7 @@ function aggregate_color_template() {
 			form_end_row();
 		}
 	} else {
-		print "<tr><td><em>" . __('No Color Templates Found') ."</em></td></tr>\n";
+		print "<tr><td colspan='" . (sizeof($display_text)+1) . "'><em>" . __('No Color Templates Found') ."</em></td></tr>\n";
 	}
 
 	html_end_box(false);
