@@ -247,7 +247,12 @@ function form_save() {
 
 						$save3['id'] = $rrd['id'];
 						$save3['local_data_id'] = $local_data_id;
-						$save3['local_data_template_rrd_id'] = db_fetch_cell_prepared('SELECT local_data_template_rrd_id FROM data_template_rrd WHERE id = ?', array($rrd['id']));
+
+						$save3['local_data_template_rrd_id'] = db_fetch_cell_prepared('SELECT local_data_template_rrd_id
+							FROM data_template_rrd
+							WHERE id = ?',
+							array($rrd['id']));
+
 						$save3['data_template_id'] = get_filter_request_var('data_template_id');
 						$save3['rrd_maximum'] = form_input_validate(get_nfilter_request_var("rrd_maximum$name_modifier"), "rrd_maximum$name_modifier", "^(-?([0-9]+(\.[0-9]*)?|[0-9]*\.[0-9]+)([eE][+\-]?[0-9]+)?)|U$|\|query_ifSpeed\||\|query_ifHighSpeed\|", false, 3);
 						$save3['rrd_minimum'] = form_input_validate(get_nfilter_request_var("rrd_minimum$name_modifier"), "rrd_minimum$name_modifier", "^(-?([0-9]+(\.[0-9]*)?|[0-9]*\.[0-9]+)([eE][+\-]?[0-9]+)?)|U$|\|query_ifSpeed\||\|query_ifHighSpeed\|", false, 3);
@@ -333,7 +338,9 @@ function form_actions() {
 
 				switch (get_request_var('delete_type')) {
 					case '2': /* delete all graph items tied to this data source */
-						$data_template_rrds = array_rekey(db_fetch_assoc('SELECT id FROM data_template_rrd WHERE ' . array_to_sql_or($selected_items, 'local_data_id')), 'id', 'id');
+						$data_template_rrds = array_rekey(db_fetch_assoc('SELECT id
+							FROM data_template_rrd
+							WHERE ' . array_to_sql_or($selected_items, 'local_data_id')), 'id', 'id');
 
 						/* loop through each data source item */
 						if (sizeof($data_template_rrds) > 0) {
@@ -369,7 +376,11 @@ function form_actions() {
 				get_filter_request_var('host_id');
 
 				for ($i=0;($i<count($selected_items));$i++) {
-					db_execute_prepared('UPDATE data_local SET host_id = ? WHERE id = ?', array(get_nfilter_request_var('host_id'), $selected_items[$i]));
+					db_execute_prepared('UPDATE data_local
+						SET host_id = ?
+						WHERE id = ?',
+						array(get_nfilter_request_var('host_id'), $selected_items[$i]));
+
 					push_out_host(get_nfilter_request_var('host_id'), $selected_items[$i]);
 					update_data_source_title_cache($selected_items[$i]);
 				}
@@ -410,7 +421,7 @@ function form_actions() {
 			input_validate_input_number($matches[1]);
 			/* ==================================================== */
 
-			$ds_list .= '<li>' . htmlspecialchars(get_data_source_title($matches[1])) . '</li>';
+			$ds_list .= '<li>' . html_escape(get_data_source_title($matches[1])) . '</li>';
 			$ds_array[$i] = $matches[1];
 
 			$i++;
@@ -569,7 +580,7 @@ function data_edit($incform = true) {
 			array($data['data_input_id'])
 		);
 
-		html_start_box( __('Custom Data [data input: %s]', htmlspecialchars(db_fetch_cell_prepared('SELECT name FROM data_input WHERE id = ?', array($data['data_input_id']))) ),'100%', '', '3', 'center', '');
+		html_start_box( __('Custom Data [data input: %s]', html_escape(db_fetch_cell_prepared('SELECT name FROM data_input WHERE id = ?', array($data['data_input_id']))) ),'100%', '', '3', 'center', '');
 
 		/* loop through each field found */
 		if (sizeof($fields) > 0) {
@@ -602,13 +613,13 @@ function data_edit($incform = true) {
 				form_alternate_row();
 
 				if ((!empty($host['id'])) && (preg_match('/^' . VALID_HOST_FIELDS . '$/i', $field['type_code']))) {
-					print "<td style='width:50%;'><strong>" . $field['name'] . '</strong> ' . __('(From Device: %s)', $host['hostname']) . "</td>\n";
-					print "<td><em>$old_value</em></td>\n";
+					print "<td style='width:50%;'><strong>" . html_escape($field['name']) . '</strong> ' . __('(From Device: %s)', html_escape($host['hostname'])) . "</td>\n";
+					print "<td><em>" . html_escape($old_value) . "</em></td>\n";
 				} elseif (empty($can_template)) {
-					print "<td style='width:50%;'><strong>" . $field['name'] . '</strong> ' . __('(From Data Template)') . "</td>\n";
-					print '<td><em>' . (empty($old_value) ? __('Nothing Entered') : $old_value) . "</em></td>\n";
+					print "<td style='width:50%;'><strong>" . html_escape($field['name']) . '</strong> ' . __('(From Data Template)') . "</td>\n";
+					print '<td><em>' . (empty($old_value) ? __('Nothing Entered') : html_escape($old_value)) . "</em></td>\n";
 				} else {
-					print "<td style='width:50%;'><strong>" . $field['name'] . "</strong></td>\n";
+					print "<td style='width:50%;'><strong>" . html_escape($field['name']) . "</strong></td>\n";
 					print '<td>';
 
 					draw_custom_data_row('value_' . $field['id'], $field['id'], $data['id'], $old_value);
@@ -864,9 +875,13 @@ function ds_edit() {
 
 	/* only display the "inputs" area if we are using a data template for this data source */
 	if (!empty($data['data_template_id'])) {
-		$template_data_rrds = db_fetch_assoc_prepared('SELECT * FROM data_template_rrd WHERE local_data_id = ? ORDER BY data_source_name', array(get_request_var('id')));
+		$template_data_rrds = db_fetch_assoc_prepared('SELECT *
+			FROM data_template_rrd
+			WHERE local_data_id = ?
+			ORDER BY data_source_name',
+			array(get_request_var('id')));
 
-		html_start_box( __('Supplemental Data Template Data'), '100%', true, '3', 'center', '');
+		html_start_box(__('Supplemental Data Template Data'), '100%', true, '3', 'center', '');
 
 		draw_nontemplated_fields_data_source($data['data_template_id'], $data['local_data_id'], $data, '|field|', __('Data Source Fields'), true, true, 0);
 		draw_nontemplated_fields_data_source_item($data['data_template_id'], $template_data_rrds, '|field|_|id|', __('Data Source Item Fields'), true, true, true, 0);
@@ -910,7 +925,11 @@ function ds_edit() {
 
 		/* fetch ALL rrd's for this data source */
 		if (!isempty_request_var('id')) {
-			$template_data_rrds = db_fetch_assoc_prepared('SELECT id, data_source_name FROM data_template_rrd WHERE local_data_id = ? ORDER BY data_source_name', array(get_request_var('id')));
+			$template_data_rrds = db_fetch_assoc_prepared('SELECT id, data_source_name
+				FROM data_template_rrd
+				WHERE local_data_id = ?
+				ORDER BY data_source_name',
+				array(get_request_var('id')));
 		}
 
 		/* select the first "rrd" of this data source by default */
@@ -920,12 +939,22 @@ function ds_edit() {
 
 		/* get more information about the rrd we chose */
 		if (!isempty_request_var('view_rrd')) {
-			$local_data_template_rrd_id = db_fetch_cell_prepared('SELECT local_data_template_rrd_id FROM data_template_rrd WHERE id = ?', array(get_request_var('view_rrd')));
+			$local_data_template_rrd_id = db_fetch_cell_prepared('SELECT local_data_template_rrd_id
+				FROM data_template_rrd
+				WHERE id = ?',
+				array(get_request_var('view_rrd')));
 
-			$rrd = db_fetch_row_prepared('SELECT * FROM data_template_rrd WHERE id = ?', array(get_request_var('view_rrd')));
-			$rrd_template = db_fetch_row_prepared('SELECT * FROM data_template_rrd WHERE id = ?', array($local_data_template_rrd_id));
+			$rrd = db_fetch_row_prepared('SELECT *
+				FROM data_template_rrd
+				WHERE id = ?',
+				array(get_request_var('view_rrd')));
 
-			$header_label = '[edit: ' . $rrd['data_source_name'] . ']';
+			$rrd_template = db_fetch_row_prepared('SELECT *
+				FROM data_template_rrd
+				WHERE id = ?',
+				array($local_data_template_rrd_id));
+
+			$header_label = __('[edit: %s]', html_escape($rrd['data_source_name']));
 		} else {
 			$header_label = '';
 		}
@@ -1139,7 +1168,10 @@ function ds() {
 	}
 
 	if (get_request_var('host_id') > 0) {
-		$host = db_fetch_row_prepared('SELECT hostname FROM host WHERE id = ?', array(get_request_var('host_id')));
+		$host = db_fetch_row_prepared('SELECT hostname
+			FROM host
+			WHERE id = ?',
+			array(get_request_var('host_id')));
 	} else {
 		$host = array();
 	}
