@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2018 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -22,9 +22,11 @@
  +-------------------------------------------------------------------------+
 */
 
+define('CACTI_PHP_VERSION_MINIMUM', '5.4.0');
+
 define('CACTI_ESCAPE_CHARACTER', '"');
-define('COPYRIGHT_YEARS', 'Copyright (C) 2004-2017 The Cacti Group');
-define('COPYRIGHT_YEARS_SHORT', '(c) 2004-2017 - The Cacti Group');
+define('COPYRIGHT_YEARS', 'Copyright (C) 2004-' . date('Y') . ' The Cacti Group');
+define('COPYRIGHT_YEARS_SHORT', '(c) 2004-' . date('Y') . ' - The Cacti Group');
 
 define('HOST_GROUPING_GRAPH_TEMPLATE', 1);
 define('HOST_GROUPING_DATA_QUERY_INDEX', 2);
@@ -303,7 +305,11 @@ define('REPORTS_TREE_NONE', 0);
 define('REPORTS_TIMESPAN_DEFAULT', GT_LAST_DAY);
 
 define('REPORTS_EXTENSION_GD', 'gd');
-define('REPORTS_DEBUG', read_config_option('reports_log_verbosity'), true);
+if (function_exists('read_config_option')) {
+	define('REPORTS_DEBUG', read_config_option('reports_log_verbosity'), true);
+} else {
+	define('REPORTS_DEBUG', 1, true);
+}
 
 define('REPORTS_OUTPUT_STDOUT', 1);
 define('REPORTS_OUTPUT_EMAIL',  2);
@@ -370,7 +376,7 @@ define('AUTOMATION_ACTION_TREE_ENABLE', 2);
 define('AUTOMATION_ACTION_TREE_DISABLE', 3);
 define('AUTOMATION_ACTION_TREE_DELETE', 99);
 
-if ($database_type == 'mysql') {
+if (isset($database_type) && $database_type == 'mysql') {
 	define('SQL_NO_CACHE', 'SQL_NO_CACHE');
 } else {
 	define('SQL_NO_CACHE', '');
