@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2018 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -13,7 +13,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -365,6 +365,16 @@ $fields_data_template_template_edit = array(
 	);
 
 /* file: (data_sources.php|data_templates.php), action: (ds|template)_edit */
+
+if (db_table_exists('data_source_profiles')) {
+	$def_profile = db_fetch_cell('SELECT id
+		FROM data_source_profiles
+		ORDER BY `default`
+		DESC LIMIT 1');
+} else {
+	$def_profile = '1';
+}
+
 $struct_data_source = array(
 	'name' => array(
 		'friendly_name' => __('Name'),
@@ -397,8 +407,8 @@ $struct_data_source = array(
 		'friendly_name' => __('Data Source Profile'),
 		'method' => 'drop_sql',
 		'description' => __('Select the Data Source Profile.  The Data Source Profile controls polling interval, the data aggregation, and retention policy for the resulting Data Sources.'),
-		'sql' => 'SELECT id, name FROM data_source_profiles ORDER BY name',
-		'none_value' => __('External'),
+		'sql' => 'SELECT "0" AS id, "' . __('External') . '" AS name UNION SELECT id, name FROM data_source_profiles ORDER BY name',
+		'default' => $def_profile,
 		'flags' => ''
 		),
 	'rrd_step' => array(
@@ -1011,6 +1021,7 @@ $fields_host_edit = array(
 		'description' => __('Choose the Device Template to use to define the default Graph Templates and Data Queries associated with this Device.'),
 		'value' => '|arg1:host_template_id|',
 		'none_value' => __('None'),
+		'default' => read_config_option('default_template'),
 		'sql' => 'SELECT id, name FROM host_template ORDER BY name',
 		),
 	'device_threads' => array(
@@ -1032,7 +1043,6 @@ $fields_host_edit = array(
 	'host_snmp_head' => array(
 		'method' => 'spacer',
 		'friendly_name' => __('SNMP Options'),
-		'collapsible' => 'true'
 		),
 	'snmp_version' => array(
 		'method' => 'drop_array',
@@ -1040,7 +1050,7 @@ $fields_host_edit = array(
 		'description' => __('Choose the SNMP version for this device.'),
 		'on_change' => 'changeHostForm()',
 		'value' => '|arg1:snmp_version|',
-		'default' => read_config_option('snmp_ver'),
+		'default' => read_config_option('snmp_version'),
 		'array' => $snmp_versions,
 		),
 	'snmp_community' => array(
@@ -1053,6 +1063,16 @@ $fields_host_edit = array(
 		'max_length' => '100',
 		'size' => '20'
 		),
+	'snmp_security_level' => array(
+		'method' => 'drop_array',
+		'friendly_name' => __('SNMP Security Level'),
+		'description' => __('SNMP v3 Security Level to user for querying the device.'),
+		'on_change' => 'setSNMP()',
+		'value' => '|arg1:snmp_security_level|',
+		'form_id' => '|arg1:id|',
+		'default' => read_config_option('snmp_security_level'),
+		'array' => $snmp_security_levels
+		),
 	'snmp_username' => array(
 		'method' => 'textbox',
 		'friendly_name' => __('SNMP Username (v3)'),
@@ -1062,6 +1082,15 @@ $fields_host_edit = array(
 		'max_length' => '50',
 		'size' => '20'
 		),
+	'snmp_auth_protocol' => array(
+		'method' => 'drop_array',
+		'friendly_name' => __('SNMP Auth Protocol (v3)'),
+		'description' => __('Choose the SNMPv3 authentication protocol.'),
+		'on_change' => 'setSNMP()',
+		'value' => '|arg1:snmp_auth_protocol|',
+		'default' => read_config_option('snmp_auth_protocol'),
+		'array' => $snmp_auth_protocols,
+		),
 	'snmp_password' => array(
 		'method' => 'textbox_password',
 		'friendly_name' => __('SNMP Password (v3)'),
@@ -1071,16 +1100,17 @@ $fields_host_edit = array(
 		'max_length' => '50',
 		'size' => '20'
 		),
-	'snmp_auth_protocol' => array(
+	'snmp_priv_protocol' => array(
 		'method' => 'drop_array',
-		'friendly_name' => __('SNMP Auth Protocol (v3)'),
-		'description' => __('Choose the SNMPv3 authentication protocol.'),
-		'value' => '|arg1:snmp_auth_protocol|',
-		'default' => read_config_option('snmp_auth_protocol'),
-		'array' => $snmp_auth_protocols,
+		'friendly_name' => __('SNMP Privacy Protocol (v3)'),
+		'description' => __('Choose the SNMPv3 privacy protocol.'),
+		'on_change' => 'setSNMP()',
+		'value' => '|arg1:snmp_priv_protocol|',
+		'default' => read_config_option('snmp_priv_protocol'),
+		'array' => $snmp_priv_protocols,
 		),
 	'snmp_priv_passphrase' => array(
-		'method' => 'textbox',
+		'method' => 'textbox_password',
 		'friendly_name' => __('SNMP Privacy Passphrase (v3)'),
 		'description' => __('Choose the SNMPv3 privacy passphrase.'),
 		'value' => '|arg1:snmp_priv_passphrase|',
@@ -1088,14 +1118,6 @@ $fields_host_edit = array(
 		'max_length' => '200',
 		'size' => '40'
 		),
-	'snmp_priv_protocol' => array(
-		'method' => 'drop_array',
-		'friendly_name' => __('SNMP Privacy Protocol (v3)'),
-		'description' => __('Choose the SNMPv3 privacy protocol.'),
-		'value' => '|arg1:snmp_priv_protocol|',
-		'default' => read_config_option('snmp_priv_protocol'),
-		'array' => $snmp_priv_protocols,
-		),
 	'snmp_context' => array(
 		'method' => 'textbox',
 		'friendly_name' => __('SNMP Context (v3)'),
@@ -1653,6 +1675,16 @@ $fields_template_import = array(
 			'max_length' => '100',
 			'size' => '20'
 			),
+		'snmp_security_level' => array(
+			'method' => 'drop_array',
+			'friendly_name' => __('SNMP Security Level'),
+			'description' => __('SNMP v3 Security Level to user for querying the device.'),
+			'on_change' => 'setSNMP()',
+			'value' => '|arg1:snmp_security_level|',
+			'form_id' => '|arg1:id|',
+			'default' => read_config_option('snmp_security_level'),
+			'array' => $snmp_security_levels
+			),
 		'snmp_username' => array(
 			'method' => 'textbox',
 			'friendly_name' => __('SNMP Username (v3)'),
@@ -1662,40 +1694,42 @@ $fields_template_import = array(
 			'max_length' => '50',
 			'size' => '20'
 			),
-		'snmp_auth_password' => array(
-			'method' => 'textbox_password',
-			'friendly_name' => __('SNMP Auth Password (v3)'),
-			'description' => __('SNMP v3 user password for this device.'),
-			'value' => '|arg1:snmp_auth_password|',
-			'default' => read_config_option('snmp_password'),
-			'max_length' => '50',
-			'size' => '20'
-			),
 		'snmp_auth_protocol' => array(
 			'method' => 'drop_array',
 			'friendly_name' => __('SNMP Auth Protocol (v3)'),
 			'description' => __('Choose the SNMPv3 Authorization Protocol.<br>Note: SHA authentication support is only available if you have OpenSSL installed.'),
+			'on_change' => 'setSNMP()',
 			'value' => '|arg1:snmp_auth_protocol|',
 			'default' => read_config_option('snmp_auth_protocol'),
 			'array' => $snmp_auth_protocols,
 			),
-		'snmp_priv_password' => array(
+		'snmp_password' => array(
 			'method' => 'textbox_password',
-			'friendly_name' => __('SNMP Privacy Password (v3)'),
-			'description' => __('Choose the SNMPv3 Privacy Passphrase.'),
-			'value' => '|arg1:snmp_priv_password|',
-			'default' => read_config_option('snmp_priv_passphrase'),
-			'max_length' => '200',
-			'size' => '40'
+			'friendly_name' => __('SNMP Auth Password (v3)'),
+			'description' => __('SNMP v3 user password for this device.'),
+			'value' => '|arg1:snmp_password|',
+			'default' => read_config_option('snmp_password'),
+			'max_length' => '50',
+			'size' => '20'
 			),
 		'snmp_priv_protocol' => array(
 			'method' => 'drop_array',
 			'friendly_name' => __('SNMP Privacy Protocol (v3)'),
 			'description' => __('Choose the SNMPv3 Privacy Protocol.<br>Note: DES/AES encryption support is only available if you have OpenSSL installed.'),
+			'on_change' => 'setSNMP()',
 			'value' => '|arg1:snmp_priv_protocol|',
 			'default' => read_config_option('snmp_priv_protocol'),
 			'array' => $snmp_priv_protocols,
 			),
+		'snmp_priv_passphrase' => array(
+			'method' => 'textbox_password',
+			'friendly_name' => __('SNMP Privacy Password (v3)'),
+			'description' => __('Choose the SNMPv3 Privacy Passphrase.'),
+			'value' => '|arg1:snmp_priv_passphrase|',
+			'default' => read_config_option('snmp_priv_passphrase'),
+			'max_length' => '200',
+			'size' => '40'
+			),
 		'snmp_engine_id' => array(
 			'friendly_name' => __('SNMP Engine ID'),
 			'description' => __('Defines the unique SNMP Engine ID to identify this peer. Following format will be recommended:<br>FlexibleLength+Enterprise(8000) + IANA-Cacti(5d75) + MAC-Following(03) + YOUR-MAC-ADDRESS(e.g.:D89D67287B00).<br>Per default the locally administrated MAC 02-FF-FF-FF-FF-FF will be used.'),
