@@ -22,14 +22,19 @@
  +-------------------------------------------------------------------------+
 */
 
-function upgrade_to_1_1_35() {
-	db_install_execute("DELETE FROM data_input_data 
-		WHERE data_input_field_id=0");
+function upgrade_to_0_8_1() {
+	db_install_add_column ('user_log', array('name' => 'user_id', 'type' => 'mediumint(8)', 'NULL' => false, 'after' => 'username'));
+	db_install_execute("ALTER TABLE user_log change time time datetime not null;");
+	db_install_execute("ALTER TABLE user_log drop primary key;");
+	db_install_execute("ALTER TABLE user_log add primary key (username, user_id, time);");
+	db_install_add_column ('user_auth', array('name' => 'realm', 'type' => 'mediumint(8)', 'NULL' => false, 'after' => 'password'));
+	db_install_execute("UPDATE user_auth set realm = 1 where full_name='ldap user';");
 
-	db_install_execute("DELETE FROM snmp_query_graph_rrd 
-		WHERE data_template_id=0 OR data_template_rrd_id=0");
+	$_src = db_fetch_assoc("select id, username from user_auth");
 
-	db_install_execute("DELETE FROM snmp_query_graph_rrd_sv 
-		WHERE data_template_id=0");
+	if (sizeof($_src) > 0) {
+		foreach ($_src as $item) {
+			db_install_execute("UPDATE user_log set user_id = " . $item["id"] . " where username = '" . $item["username"] . "';");
+		}
+	}
 }
-
