@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2018 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -13,7 +13,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -111,7 +111,7 @@ Error codes:
 
 #	Text
 ==============================================================
-0	User found
+0	Authentication Success
 1	No username defined
 2	Unable to create LDAP connection object
 3	Unable to find users DN
@@ -126,6 +126,7 @@ Error codes:
 12	Unable to set referrals option
 13	More than one matching user found
 14	Specific DN and Password required
+15	Unable to find user from DN
 99	PHP LDAP not enabled
 
 */
@@ -151,6 +152,116 @@ function cacti_ldap_search_dn($username, $dn = '', $host = '', $port = '', $port
 	return $ldap->Search();
 }
 
+abstract class LdapError {
+	const None                  = 0;
+	const Success               = 0;
+	const Failure               = 1;
+	const UndefinedUsername     = 2;
+	const ProtocolErrorVersion  = 3;
+	const ProtocolErrorReferral = 4;
+	const ProtocolErrorTls      = 5;
+	const MissingLdapObject     = 6;
+	const ProtocolErrorGeneral  = 7;
+	const InsufficientAccess    = 8;
+	const ConnectionUnavailable = 9;
+	const ConnectionTimeout     = 10;
+	const ProtocolErrorBind     = 11;
+	const SearchFoundNoGroup    = 12;
+	const SearchFoundMultiUser  = 13;
+	const SearchFoundNoUser     = 14;
+	const SearchFoundNoUserDN   = 15;
+	const UndefinedDnOrPassword = 16;
+	const Disabled              = 99;
+
+	public static function GetErrorDetails($returnError, $ldapConn = null, $ldapError = 0) {
+		$error_num = $returnError;
+		if ($returnError > 0 && $ldapError == 0 && $ldapConn > 0) {
+			$ldapError = ldap_error($ldapConn);
+		}
+
+		switch ($returnError) {
+			case LdapError::None:
+			case LdapError::Success:
+				$error_text = __('Authentication Success');
+				break;
+
+			case LdapError::Failure:
+				$error_text = __('Authentication Failure');
+				break;
+
+			case LdapError::Disabled:
+				$error_text = __('PHP LDAP not enabled');
+				break;
+
+			case LdapError::UndefinedUsername:
+				$error_text = __('No username defined');
+				break;
+
+			case LdapError::ProtocolErrorVersion:
+				$error_text = __('Protocol Error, Unable to set version');
+				break;
+
+			case LdapError::ProtocolErrorReferral:
+				$error_text = __('Protocol Error, Unable to set referrals option');
+				break;
+
+			case LdapError::ProtocolErrorTls:
+				$error_text = __('Protocol Error, unable to start TLS communications');
+				break;
+
+			case LdapError::ProtocolErrorGeneral:
+				$error_text = __('Protocol Error, General failure (%s)', $ldapError);
+				break;
+
+			case LdapError::ProtocolErrorBind:
+				$error_text = __('Protocol Error, Unable to bind, LDAP result: %s', $ldapError);
+				break;
+
+			case LdapError::ConnectionUnavailable:
+				$error_text = __('Unable to Connect to Server');
+				break;
+
+			case LdapError::ConnectionTimeout:
+				$error_text =  __('Connection Timeout');
+				break;
+
+			case LdapError::InsufficientAccess:
+				$error_text = __('Insufficient access');
+				break;
+
+			case LdapError::SearchFoundNoGroup:
+				$error_text = __('Group DN could not be found to compare');
+				break;
+
+			case LdapError::SearchFoundMultiUser:
+				$error_text = __('More than one matching user found');
+				break;
+
+			case LdapError::SearchFoundNoUserDN:
+				$error_text = __('Unable to find user from DN');
+				break;
+
+			case LdapError::SearchFoundNoUser:
+				$error_text = __('Unable to find users DN');
+				break;
+
+			case LdapError::MissingLdapObject:
+				$error_text = __('Unable to create LDAP connection object');
+				break;
+
+			case LdapError::UndefinedDnOrPassword:
+				$error_text = __('Specific DN and Password required');
+				break;
+
+			default:
+				$error_text = __('Unexpected error %s (Ldap Error: %s)', $returnError, $ldapError);
+				break;
+		}
+
+		return array('error_num' => $error_num, 'error_text' => $error_text, 'error_ldap' => $ldapError, 'dn' => '');
+	}
+}
+
 class Ldap {
 	function __construct() {
 		/* Initialize LDAP parameters for Authenticate */
@@ -211,17 +322,12 @@ class Ldap {
 
 		/* function check */
 		if (!function_exists('ldap_connect')) {
-			$output['error_num'] = 99;
-			$output['error_text'] = __('PHP LDAP not enabled');
-			return $output;
+			return LdapError::GetErrorDetails(LdapError::Disabled);
 		}
 
 		/* validation */
 		if (empty($this->username)) {
-			$output['error_num'] = '2';
-			$output['error_text'] = __('No username defined');
-
-			return $output;
+			return LdapError::GetErrorDetails(LdapError::UndefinedUsername);
 		}
 
 		$this->dn = str_replace('<username>', $this->username, $this->dn);
@@ -245,8 +351,7 @@ class Ldap {
 			cacti_log('LDAP: Setting protocol version to ' . $this->version, false, 'AUTH');
 
 			if (!ldap_set_option($ldap_conn, LDAP_OPT_PROTOCOL_VERSION, $this->version)) {
-				$output['error_num'] = '3';
-				$output['error_text'] = __('Protocol Error, Unable to set version');
+				$output = LdapError::GetErrorDetails(LdapError::ProtocolErrorVersion);
 				cacti_log('LDAP: ' . $output['error_text'], false, 'AUTH');
 				ldap_close($ldap_conn);
 				$this->RestoreCactiHandler();
@@ -256,8 +361,7 @@ class Ldap {
 			/* set referrals */
 			if ($this->referrals == '0') {
 				if (!ldap_set_option($ldap_conn, LDAP_OPT_REFERRALS, 0)) {
-					$output['error_num'] = '4';
-					$output['error_text'] = __('Unable to set referrals option');
+					$output = LdapError::GetErrorDetails(LdapError::ProtocolErrorReferral);
 					cacti_log('LDAP: ' . $output['error_text'], false, 'AUTH');
 					ldap_close($ldap_conn);
 					$this->RestoreCactiHandler();
@@ -268,8 +372,7 @@ class Ldap {
 			/* start TLS if requested */
 			if ($this->encryption == '2') {
 				if (!ldap_start_tls($ldap_conn)) {
-					$output['error_num'] = '5';
-					$output['error_text'] = __('Protocol Error, unable to start TLS communications');
+					$output = LdapError::GetErrorDetails(LdapError::ProtocolErrorTls);
 					cacti_log('LDAP: ' . $output['error_text'], false, 'AUTH');
 					ldap_close($ldap_conn);
 					$this->RestoreCactiHandler();
@@ -307,18 +410,15 @@ class Ldap {
 
 					if ($ldap_group_response === true) {
 						/* Auth ok */
-						$output['error_num'] = '0';
-						$output['error_text'] = __('Authentication Success');
+						$output = LdapError::GetErrorDetails(LdapError::Success);
 					} else if ($ldap_group_response === false) {
-						$output['error_num'] = '8';
-						$output['error_text'] = __('Insufficient access');
+						$output = LdapError::GetErrorDetails(LdapError::InsufficientAccess);
 						cacti_log('LDAP: ' . $output['error_text'], false, 'AUTH');
 						ldap_close($ldap_conn);
 						$this->RestoreCactiHandler();
 						return $output;
 					} else {
-						$output['error_num'] = '12';
-						$output['error_text'] = __('Group DN could not be found to compare');
+						$output = LdapError::GetErrorDetails(LdapError::SearchFoundNoGroup);
 						cacti_log('LDAP: ' . $output['error_text'], false, 'AUTH');
 						ldap_close($ldap_conn);
 						$this->RestoreCactiHandler();
@@ -326,42 +426,34 @@ class Ldap {
 					}
 				} else {
 					/* Auth ok - No group membership required */
-					$output['error_num'] = '0';
-					$output['error_text'] = __('Authentication Success');
+					$output = LdapError::GetErrorDetails(LdapError::Success);
 				}
 			} else {
 				/* unable to bind */
 				$ldap_error = ldap_errno($ldap_conn);
 				if ($ldap_error == 0x03) {
 					/* protocol error */
-					$output['error_num'] = '7';
-					$output['error_text'] = __('Protocol Error');
+					$ouptut = LdapError::GetErrorDetails(LdapError::ProtocolErrorGeneral, null, $ldap_error);
 				} elseif ($ldap_error == 0x31) {
 					/* invalid credentials */
-					$output['error_num'] = '1';
-					$output['error_text'] = __('Authentication Failure');
+					$output = LdapError::GetErrorDetails(LdapError::Failure);
 				} elseif ($ldap_error == 0x32) {
 					/* insuffient access */
-					$output['error_num'] = '8';
-					$output['error_text'] = __('Insufficient Access');
+					$output = LdapError::GetErrorDetails(LdapError::InsufficientAccess);
 				} elseif ($ldap_error == 0x51) {
 					/* unable to connect to server */
-					$output['error_num'] = '9';
-					$output['error_text'] = __('Unable to Connect to Server');
+					$output = LdapError::GetErrorDetails(LdapError::ConnectionUnavailable);
 				} elseif ($ldap_error == 0x55) {
 					/* timeout */
-					$output['error_num'] = '10';
-					$output['error_text'] = __('Connection Timeout');
+					$output = LdapError::GetErrorDetails(LdapError::ConnectionTimeout);
 				} else {
 					/* general bind error */
-					$output['error_num'] = '11';
-					$output['error_text'] = __('General Bind Error, LDAP result:') . ' ' . ldap_error($ldap_conn);
+					$output = LdapError::GetErrorDetails(LdapError::ProtocolErrorBind, null, $ldap_error);
 				}
 			}
 		} else {
 			/* Error intializing LDAP */
-			$output['error_num'] = '6';
-			$output['error_text'] = __('Unable to Create LDAP Object');
+			$output = LdapError::GetErrorDetails(LdapError::MissingLdapObject);
 		}
 
 		/* Close LDAP connection */
@@ -389,18 +481,13 @@ class Ldap {
 
 		/* function check */
 		if (!function_exists('ldap_connect')) {
-			$output['error_num'] = 99;
-			$output['error_text'] = __('PHP LDAP not enabled');
-			return $output;
+			return LdapError::GetErrorDetails(LdapError::Disabled);
 		}
 
 		/* validation */
 		if (empty($this->username)) {
-			$output['dn'] = '';
-			$output['error_num'] = '1';
-			$output['error_text'] = __('No username defined');
 			cacti_log('LDAP_SEARCH: No username defined', false, 'AUTH');
-			return $output;
+			return LdapError::GetErrorDetails(LdapError::UndefinedUsername);
 		}
 
 		/* Encode username */
@@ -412,16 +499,14 @@ class Ldap {
 
 		if ($this->mode == '0') {
 			/* Just bind mode, make dn and return */
+			$output = LdapError::GetErrorDetails(LdapError::Success);
 			$output['dn'] = $this->dn;
-			$output['error_num'] = '0';
-			$output['error_text'] = __('User found');
 			return $output;
 		} elseif ($this->mode == '2') {
 			/* Specific */
 			if (empty($this->specific_dn) || empty($this->specific_password)) {
+				$output = LdapError::GetErrorDetails(LdapError::UndefinedDnOrPassword);
 				$output['dn'] = $this->dn;
-				$output['error_num'] = '14';
-				$output['error_text'] = __('Specific DN and Password required');
 				return $output;
 			}
 		} elseif ($this->mode == '1'){
@@ -448,9 +533,7 @@ class Ldap {
 			/* Set protocol version */
 			if (!@ldap_set_option($ldap_conn, LDAP_OPT_PROTOCOL_VERSION, $this->version)) {
 				/* protocol error */
-				$output['dn'] = '';
-				$output['error_num'] = '4';
-				$output['error_text'] = __('Protocol Error, unable to set version');
+				$output = LdapError::GetErrorDetails(LdapError::ProtocolErrorVersion);
 				cacti_log('LDAP_SEARCH: ' . $output['error_text'], false, 'AUTH');
 				@ldap_close($ldap_conn);
 				return $output;
@@ -460,9 +543,7 @@ class Ldap {
 			if ($this->referrals == '0') {
 				if (!@ldap_set_option($ldap_conn, LDAP_OPT_REFERRALS, 0)) {
 					/* referrals set error */
-					$output['dn'] = '';
-					$output['error_num'] = '13';
-					$output['error_text'] = __('Unable to set referrals option');
+					$output = LdapError::GetErrorDetails(LdapError::ProtocolErrorReferral);
 					cacti_log('LDAP_SEARCH: ' . $output['error_text'], false, 'AUTH');
 					@ldap_close($ldap_conn);
 					return $output;
@@ -473,9 +554,7 @@ class Ldap {
 			if ($this->encryption == '2') {
 				if (!@ldap_start_tls($ldap_conn)) {
 					/* TLS startup error */
-					$output['dn'] = '';
-					$output['error_num'] = '5';
-					$output['error_text'] = __('Protocol Error, unable to start TLS communications');
+					$output = LdapError::GetErrorDetails(LdapError::ProtocolErrorTls);
 					cacti_log('LDAP_SEARCH: ' . $output['error_text'], false, 'AUTH');
 					@ldap_close($ldap_conn);
 					return $output;
@@ -491,67 +570,46 @@ class Ldap {
 
 					if ($ldap_entries['count'] == '1') {
 						/* single response return user dn */
+						$output = LdapError::GetErrorDetails(LdapError::Success);
 						$output['dn'] = $ldap_entries['0']['dn'];
-						$output['error_num'] = '0';
-						$output['error_text'] = __('User found');
-						cacti_log("LDAP_SEARCH: User found, DN '%s'" . $output['dn'], false, 'AUTH');
+						cacti_log('LDAP_SEARCH: ' . $output['error_text'] . ', DN \'' . $output['dn'] . '\'', false, 'AUTH');
 					} elseif ($ldap_entries['count'] > 1) {
 						/* more than 1 result */
-						$output['dn'] = '';
-						$output['error_num'] = '13';
-						$output['error_text'] = __('More than one matching user found');
+						$output = LdapError::GetErrorDetails(LdapError::SearchFoundMultiUser);
 					} else {
 						/* no search results */
-						$output['dn'] = '';
-						$output['error_num'] = '3';
-						$output['error_text'] = __('Unable to find users DN');
+						$output = LdapError::GetErrorDetails(LdapError::SearchFoundNoUserDN);
 					}
 				} else {
 					/* no search results, user not found*/
-					$output['dn'] = '';
-					$output['error_num'] = '3';
-					$output['error_text'] = __('Unable to find users DN');
+					$output = LdapError::GetErrorDetails(LdapError::SearchFoundNoUser);
 				}
 			} else {
 				/* unable to bind */
 				$ldap_error = ldap_errno($ldap_conn);
 				if ($ldap_error == 0x03) {
 					/* protocol error */
-					$output['dn'] = '';
-					$output['error_num'] = '6';
-					$output['error_text'] = __('Protocol Error');
+					$output = LdapError::GetErrorDetails(LdapError::ProtocolErrorGeneral,null,$ldapError);
 				} elseif ($ldap_error == 0x31) {
 					/* invalid credentials */
-					$output['dn'] = '';
-					$output['error_num'] = '7';
-					$output['error_text'] = __('Invalid Credentials');
+					$output = LdapError::GetErrorDetails(LdapError::Failure);
 				} elseif ($ldap_error == 0x32) {
 					/* insuffient access */
-					$output['dn'] = '';
-					$output['error_num'] = '8';
-					$output['error_text'] = __('Insufficient Access');
+					$output = LdapError::GetErrorDetails(LdapError::InsufficientAccess);
 				} elseif ($ldap_error == 0x51) {
 					/* unable to connect to server */
-					$output['dn'] = '';
-					$output['error_num'] = '9';
-					$output['error_text'] = __('Unable to Connect to Server');
+					$output = LdapError::GetErrorDetails(LdapError::ConnectionUnavailable);
 				} elseif ($ldap_error == 0x55) {
 					/* timeout */
-					$output['dn'] = '';
-					$output['error_num'] = '10';
-					$output['error_text'] = __('Connection Timeout');
+					$output = LdapError::GetErrorDetails(LdapError::ConnectionTimeout);
 				} else {
 					/* general bind error */
-					$output['dn'] = '';
-					$output['error_num'] = '11';
-					$output['error_text'] = __('General Bind Error, LDAP result:') . ' ' . ldap_error($ldap_conn);
+					$output = LdapError::GetErrorDetails(LdapError::ProtocolErrorBind, null, $ldap_error);
 				}
 			}
 		} else {
 			/* unable to setup connection */
-			$output['dn'] = '';
-			$output['error_num'] = '2';
-			$output['error_text'] = __('Unable to create LDAP connection object');
+			$output = LdapError::GetErrorDetails(LdapError::MissingLdapObject);
 		}
 
 		@ldap_close($ldap_conn);
