@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2018 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -548,6 +548,7 @@ function update_resource_cache($poller_id = 1) {
 		'resource' => array('recursive' => true,  'path' => $rpath),
 		'lib'      => array('recursive' => true,  'path' => $mpath . '/lib'),
 		'include'  => array('recursive' => true,  'path' => $mpath . '/include'),
+		'install'  => array('recursive' => true,  'path' => $mpath . '/install'),
 		'formats'  => array('recursive' => true,  'path' => $mpath . '/formats'),
 		'locales'  => array('recursive' => true,  'path' => $mpath . '/locales'),
 		'images'   => array('recursive' => true,  'path' => $mpath . '/images'),
@@ -646,17 +647,17 @@ function update_resource_cache($poller_id = 1) {
 		if (sizeof($cache)) {
 			foreach($cache as $item) {
 				if (!file_exists($item['path'])) {
-					db_execute_prepared('DELETE FROM poller_resource_cache 
-						WHERE path = ?', 
+					db_execute_prepared('DELETE FROM poller_resource_cache
+						WHERE path = ?',
 						array($item['path']));
 				}
 			}
 		}
 	} elseif ($poller_id > 1) {
 		$paths['plugins'] = array('recursive' => true, 'path' => $mpath . '/plugins');
-		$plugin_paths = db_fetch_assoc('SELECT resource_type, path 
-			FROM poller_resource_cache 
-			WHERE path LIKE "plugins/%" 
+		$plugin_paths = db_fetch_assoc('SELECT resource_type, path
+			FROM poller_resource_cache
+			WHERE path LIKE "plugins/%"
 			GROUP BY resource_type');
 
 		if (sizeof($plugin_paths)) {
@@ -828,9 +829,9 @@ function resource_cache_out($type, $path) {
 	$curr_md5      = md5sum_path($path['path']);
 
 	if (empty($last_md5) || $last_md5 != $curr_md5) {
-		$entries = db_fetch_assoc_prepared('SELECT id, path, md5sum 
-			FROM poller_resource_cache 
-			WHERE resource_type = ?', 
+		$entries = db_fetch_assoc_prepared('SELECT id, path, md5sum
+			FROM poller_resource_cache
+			WHERE resource_type = ?',
 			array($type));
 
 		if (sizeof($entries)) {
@@ -859,15 +860,10 @@ function resource_cache_out($type, $path) {
 
 						/* if the file type is PHP check syntax */
 						if ($extension == 'php') {
-							if ($config['cacti_server_os'] == 'win32') {
-								$tmpfile = '%TEMP%' . DIRECTORY_SEPARATOR . 'cachecheck.php';
-								$tmpdir  = '%TEMP%';
-							} else {
-								$tmpfile = '/tmp/cachecheck.php';
-								$tmpdir  = '/tmp';
-							}
+							$tmpdir = sys_get_temp_dir();
+							$tmpfile = tempnam($tmpdir,'ccp');
 
-							if ((is_writeable($tmpdir) && !file_exists($tmpfile)) || (file_exists($tmpfile) && !is_writable($tmpfile))) {
+							if ((is_writeable($tmpdir) && !file_exists($tmpfile)) || (file_exists($tmpfile) && is_writable($tmpfile))) {
 								if (file_put_contents($tmpfile, $contents) !== false) {
 									$output = system($php_path . ' -l ' . $tmpfile, $exit);
 									if ($exit == 0) {
@@ -878,7 +874,8 @@ function resource_cache_out($type, $path) {
 											cacti_log("ERROR: Cache in cannot write to '" . $mypath . "', purge this location");
 										}
 									} else {
-										cacti_log("ERROR: PHP Source File '" . $mypath . "' from Cache has a Syntax error!", false, 'POLLER');
+										cacti_log("ERROR: PHP Source File '" . $mypath . "' from Cache has an error whilst checking syntax ($exit) whilst executing: $php_path -l $tmpfile", false, 'POLLER');
+										cacti_log("ERROR: PHP Source File '" . $mypath . "': " . str_replace("\n"," ",str_replace("\t"," ", $output)), false, 'POLLER');
 									}
 
 									unlink($tmpfile);
@@ -958,9 +955,9 @@ function replicate_out($remote_poller_id = 1) {
 	global $config;
 
 	if ($config['poller_id'] == 1) {
-		$cinfo = db_fetch_row_prepared('SELECT * 
-			FROM poller 
-			WHERE id = ?', 
+		$cinfo = db_fetch_row_prepared('SELECT *
+			FROM poller
+			WHERE id = ?',
 			array($remote_poller_id));
 
 		if (!sizeof($cinfo)) {
