@@ -2,7 +2,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2018 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -174,15 +174,36 @@ $process_leveling = read_config_option('process_leveling');
 // retreive the number of concurrent process settings
 $concurrent_processes = read_config_option('concurrent_processes');
 
+// correct for possible poller output not empty occurances
+$ds_needing_fixes = db_fetch_assoc_prepared('SELECT local_data_id,
+	MIN(rrd_next_step) AS next_step,
+	COUNT(DISTINCT rrd_next_step) AS instances
+	FROM poller_item
+	WHERE poller_id = ?
+	AND rrd_num > 1
+	GROUP BY local_data_id
+	HAVING instances > 1',
+	array($poller_id));
+
+if (sizeof($ds_needing_fixes)) {
+	foreach($ds_needing_fixes as $ds) {
+		db_execute_prepared('UPDATE poller_item
+			SET rrd_next_step = ?
+			WHERE local_data_id = ?',
+			array($ds['next_step'], $ds['local_data_id']));
+	}
+}
+
 // assume a scheduled task of either 60 or 300 seconds
-if (isset($poller_interval)) {
+if (!empty($poller_interval)) {
 	$poller_runs = intval($cron_interval / $poller_interval);
 	$sql_where   = 'WHERE rrd_next_step<=0 AND poller_id = ' . $poller_id;
 
 	define('MAX_POLLER_RUNTIME', $poller_runs * $poller_interval - 2);
 } else {
-	$sql_where   = 'WHERE poller_id = ' . $poller_id;
-	$poller_runs = 1;
+	$sql_where       = 'WHERE poller_id = ' . $poller_id;
+	$poller_runs     = 1;
+	$poller_interval = 300;
 	define('MAX_POLLER_RUNTIME', 298);
 }
 
@@ -487,7 +508,7 @@ while ($poller_runs_completed < $poller_runs) {
 		if ($host_count > 1) {
 			$last_host = $item['id'];
 
-			exec_background($command_string, "$extra_args --poller=$poller_id --first=$first_host --last=$last_host");
+			exec_background($command_string, "$extra_args --poller=$poller_id --first=$first_host --last=$last_host" . ($mibs ? ' --mibs':''));
 			usleep(100000);
 
 			$started_processes++;
