@@ -189,11 +189,11 @@ function tree_check_sequences() {
 
 	// report any bad or duplicate sequencs to the log for reporting purposes
 	if ($bad_seq > 0) {
-		cacti_log('WARN: Found ' . $bad_seq . ' Sequences in graph_tree Table', false, 'TREE', POLLER_DEBUG_VERBOSITY_HIGH);
+		cacti_log('WARN: Found ' . $bad_seq . ' Sequences in graph_tree Table', false, 'TREE', POLLER_VERBOSITY_HIGH);
 	}
 
 	if ($dup_seq > 0) {
-		cacti_log('WARN: Found ' . $dup_seq . ' Sequences in graph_tree Table', false, 'TREE', POLLER_DEBUG_VERBOSITY_HIGH);
+		cacti_log('WARN: Found ' . $dup_seq . ' Sequences in graph_tree Table', false, 'TREE', POLLER_VERBOSITY_HIGH);
 	}
 
 	if ($bad_seq > 0 || $dup_seq > 0) {
@@ -485,7 +485,7 @@ function form_save() {
 		$save['modified_by']   = $_SESSION['sess_user_id'];
 
 		if (empty($save['sequence'])) {
-			$save['sequence'] = get_max_tree_sequence() + 1;
+			$save['sequence'] = tree_get_max_sequence() + 1;
 		}
 
 		if (empty($save['id'])) {
@@ -850,28 +850,40 @@ function tree_edit() {
 		};
 
 		function getGraphData() {
-			$.get('tree.php?action=graphs&filter='+$('#grfilter').val(), function(data) {
-				$('#graphs').jstree('destroy');
-				$('#graphs').html(data);
-				dragable('#graphs');
-			});
+			$.get('tree.php?action=graphs&filter='+$('#grfilter').val())
+				.done(function(data) {
+					$('#graphs').jstree('destroy');
+					$('#graphs').html(data);
+					dragable('#graphs');
+				})
+				.fail(function(data) {
+					getPresentHTTPError(data);
+				});
 		}
 
 		function getHostData() {
-			$.get('tree.php?action=hosts&filter='+$('#hfilter').val(), function(data) {
-				$('#hosts').jstree('destroy');
-				$('#hosts').html(data);
-				dragable('#hosts');
-			});
+			$.get('tree.php?action=hosts&filter='+$('#hfilter').val())
+				.done(function(data) {
+					$('#hosts').jstree('destroy');
+					$('#hosts').html(data);
+					dragable('#hosts');
+				})
+				.fail(function(data) {
+					getPresentHTTPError(data);
+				});
 		}
 
 		function setHostSortIcon(nodeid) {
 			if (hostSortInfo[nodeid]) {
 				// Already set
 			} else {
-				$.get('tree.php?action=get_host_sort&nodeid='+nodeid, function(data) {
-					hostSortInfo[nodeid] = data;
-				});
+				$.get('tree.php?action=get_host_sort&nodeid='+nodeid)
+					.done(function(data) {
+						hostSortInfo[nodeid] = data;
+					})
+					.fail(function(data) {
+						getPresentHTTPError(data);
+					});
 			}
 		}
 
@@ -879,9 +891,13 @@ function tree_edit() {
 			if (branchSortInfo[nodeid]) {
 				// Already set
 			} else {
-				$.get('tree.php?action=get_branch_sort&nodeid='+nodeid, function(data) {
-					branchSortInfo[nodeid] = data;
-				});
+				$.get('tree.php?action=get_branch_sort&nodeid='+nodeid)
+					.done(function(data) {
+						branchSortInfo[nodeid] = data;
+					})
+					.fail(function(data) {
+						getPresentHTTPError(data);
+					});
 			}
 		}
 
@@ -902,15 +918,23 @@ function tree_edit() {
 		}
 
 		function setBranchSortOrder(type, nodeid) {
-			$.get('tree.php?action=set_branch_sort&type='+type+'&nodeid='+nodeid, function(data) {
-				branchSortInfo[nodeid] = type;
-			});
+			$.get('tree.php?action=set_branch_sort&type='+type+'&nodeid='+nodeid)
+				.done(function(data) {
+					branchSortInfo[nodeid] = type;
+				})
+				.fail(function(data) {
+					getPresentHTTPError(data);
+				});
 		}
 
 		function setHostSortOrder(type, nodeid) {
-			$.get('tree.php?action=set_host_sort&type='+type+'&nodeid='+nodeid, function(data) {
-				hostSortInfo[nodeid] = type;
-			});
+			$.get('tree.php?action=set_host_sort&type='+type+'&nodeid='+nodeid)
+				.done(function(data) {
+					hostSortInfo[nodeid] = type;
+				})
+				.fail(function(data) {
+					getPresentHTTPError(data);
+				});
 		}
 
 		graphsDropSet = '';
@@ -1051,6 +1075,9 @@ function tree_edit() {
 							var st = data.instance.get_state();
 							data.instance.load_node(data.instance.get_parent(data.node.id), function () { this.set_state(st); });
 						}
+					})
+					.fail(function(data) {
+						getPresentHTTPError(data);
 					});
 			})
 			.on('move_node.jstree', function (e, data) {
@@ -1076,7 +1103,7 @@ function tree_edit() {
 							.always(function () {
 								var st = data.instance.get_state();
 								data.instance.load_node(data.instance.get_parent(data.node.id), function () { this.set_state(st); });
-							});
+							})
 					});
 
 					if (oid.search('thost') >= 0) {
@@ -1531,7 +1558,7 @@ function display_graphs() {
 	if (sizeof($graphs)) {
 		foreach($graphs as $g) {
 			if (is_graph_allowed($g['id'])) {
-				echo "<ul><li id='tgraph:" . $g['id'] . "' data-jstree='{ \"type\": \"graph\" }'>" . $g['title'] . '</li></ul>';
+				echo "<ul><li id='tgraph:" . $g['id'] . "' data-jstree='{ \"type\": \"graph\" }'>" . html_escape($g['title']) . '</li></ul>';
 			}
 		}
 	}
@@ -1742,7 +1769,10 @@ function tree() {
 		foreach ($trees as $tree) {
 			$sequence = '';
 			if (get_request_var('sort_column') == 'sequence' && get_request_var('sort_direction') == 'ASC') {
-				if ($i == 1) {
+				if ($i == 1 && sizeof($trees) == 1) {
+					$sequence .= '<span class="moveArrowNone"></span>';
+					$sequence .= '<span class="moveArrowNone"></span>';
+				} elseif ($i == 1) {
 					$sequence .= '<a class="pic fa fa-caret-down moveArrow" href="' . htmlspecialchars('tree.php?action=tree_down&id=' . $tree['id']) . '" title="' . __esc('Move Down') . '"></a>';
 					$sequence .= '<span class="moveArrowNone"></span>';
 				} elseif ($i == sizeof($trees)) {
