@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2018 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -13,7 +13,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -177,7 +177,7 @@ function utilities_view_tech($php_info = '') {
 		$snmp_version = "<span class='deviceDown'>" . __('NET-SNMP Not Installed or its paths are not set.  Please install if you wish to monitor SNMP enabled devices.') . "</span>";
 	}
 
-	/* Check RRDTool issues */
+	/* Check RRDtool issues */
 	$rrdtool_error = '';
 	if ($rrdtool_version != read_config_option('rrdtool_version')) {
 		$rrdtool_error .= "<br><span class='deviceDown'>" . __('ERROR: Installed RRDtool version does not match configured version.<br>Please visit the %s and select the correct RRDtool Utility Version.', "<a href='" . html_escape('settings.php?tab=general') . "'>" . __('Configuration Settings') . '</a>') . "</span><br>";
@@ -879,6 +879,11 @@ function utilities_view_logfile() {
 	global $log_tail_lines, $page_refresh_interval, $config;
 
 	$logfile = read_config_option('path_cactilog');
+	$logbase = basename($logfile);
+
+	if (is_base64_encoded(get_nfilter_request_var('rfilter'))) {
+		set_request_var('rfilter', base64_decode(get_nfilter_request_var('rfilter')));
+	}
 
 	if (isset_request_var('filename')) {
 		$requestedFile = dirname($logfile) . '/' . basename(get_nfilter_request_var('filename'));
@@ -893,6 +898,14 @@ function utilities_view_logfile() {
 		$logfile = $config['base_path'] . '/log/cacti.log';
 	}
 
+	if (get_nfilter_request_var('filename') != '') {
+		if (strpos(get_nfilter_request_var('filename'), $logbase) === false) {
+			raise_message('clog_invalid');
+			header('Location: utilities.php?action=view_logfile&filename=' . $logbase);
+			exit(0);
+		}
+	}
+
 	/* ================= input validation and session storage ================= */
 	$filters = array(
 		'page' => array(
@@ -970,14 +983,15 @@ function utilities_view_logfile() {
 	});
 
 	function applyFilter() {
-		strURL  = urlPath+'utilities.php?tail_lines=' + $('#tail_lines').val();
-		strURL += '&message_type=' + $('#message_type').val();
-		strURL += '&refresh=' + $('#refresh').val();
-		strURL += '&reverse=' + $('#reverse').val();
-		strURL += '&rfilter=' + $('#rfilter').val();
-		strURL += '&filename=' + $('#filename').val();
-		strURL += '&action=view_logfile';
-		strURL += '&header=false';
+		strURL  = urlPath+'utilities.php' +
+			'?tail_lines=' + $('#tail_lines').val() +
+			'&message_type=' + $('#message_type').val() +
+			'&refresh=' + $('#refresh').val() +
+			'&reverse=' + $('#reverse').val() +
+			'&rfilter=' + base64_encode($('#rfilter').val()) +
+			'&filename=' + $('#filename').val() +
+			'&action=view_logfile' +
+			'&header=false';
 		refreshMSeconds=$('#refresh').val()*1000;
 		loadPageNoHeader(strURL);
 	}
@@ -1003,10 +1017,17 @@ function utilities_view_logfile() {
 						<?php print __('File');?>
 					</td>
 					<td>
-						<select id='filename' name='filename'>
+						<select id='filename'>
 							<?php
-							$selectedFile = basename(get_nfilter_request_var('filename'));
-							$logPath      = dirname(read_config_option('path_cactilog'));
+							$configLogPath = read_config_option('path_cactilog');
+							$configLogBase = basename($configLogPath);
+							$selectedFile  = basename(get_nfilter_request_var('filename'));
+
+							if ($configLogPath == '') {
+								$logPath = $config['base_path'] . '/log/';
+							} else {
+								$logPath = dirname($configLogPath);
+							}
 
 							if (is_readable($logPath)) {
 								$files = scandir($logPath);
@@ -1014,17 +1035,24 @@ function utilities_view_logfile() {
 								$files = array('cacti.log');
 							}
 
-							foreach($files as $logFile) {
-								if (in_array($logFile, array('.', '..', '.htaccess'))) {
-									continue;
-								}
+							if (sizeof($files)) {
+								foreach($files as $logFile) {
+									if (in_array($logFile, array('.', '..', '.htaccess'))) {
+										continue;
+									}
 
-								print "<option value='" . $logFile . "'";
-								if ($selectedFile == $logFile) {
-									print ' selected';
-								}
+									if (strpos($logFile, $configLogBase) === false) {
+										continue;
+									}
 
-								print '>' . $logFile . "</option>\n";
+									print "<option value='" . $logFile . "'";
+
+									if ($selectedFile == $logFile) {
+										print ' selected';
+									}
+
+									print '>' . $logFile . "</option>\n";
+								}
 							}
 							?>
 						</select>
@@ -1250,6 +1278,10 @@ function utilities_view_snmp_cache() {
 			'default' => '',
 			'options' => array('options' => 'sanitize_search_string')
 			),
+		'with_index' => array(
+			'filter' => FILTER_VALIDATE_INT,
+			'default' => '0'
+			),
 		'host_id' => array(
 			'filter' => FILTER_VALIDATE_INT,
 			'pageset' => true,
@@ -1288,6 +1320,11 @@ function utilities_view_snmp_cache() {
 	function applyFilter() {
 		strURL  = urlPath+'utilities.php?host_id=' + $('#host_id').val();
 		strURL += '&snmp_query_id=' + $('#snmp_query_id').val();
+		if ($('#with_index').is(':checked')) {
+			strURL += '&with_index=1';
+		} else {
+			strURL += '&with_index=0';
+		}
 		strURL += '&filter=' + $('#filter').val();
 		strURL += '&rows=' + $('#rows').val();
 		strURL += '&action=view_snmp_cache';
@@ -1325,12 +1362,6 @@ function utilities_view_snmp_cache() {
 		<form id='form_snmpcache' action='utilities.php'>
 			<table class='filterTable'>
 				<tr>
-					<td>
-						<?php print __('Search');?>
-					</td>
-					<td>
-						<input id='filter' type='text' size='25' value='<?php print html_escape_request_var('filter');?>'>
-					</td>
 					<?php print html_host_filter(get_request_var('host_id'));?>
 					<td>
 						<?php print __('Query Name');?>
@@ -1365,6 +1396,22 @@ function utilities_view_snmp_cache() {
 							?>
 						</select>
 					</td>
+					<td>
+						<span>
+							<input type='submit' id='refresh' value='<?php print __esc_x('Button: use filter settings', 'Go');?>' title='<?php print __esc('Set/Refresh Filters');?>'>
+							<input type='button' id='clear' value='<?php print __esc_x('Button: reset filter settings', 'Clear');?>' title='<?php print __esc('Clear Filters');?>'>
+						</span>
+					</td>
+				</tr>
+			</table>
+			<table class='filterTable'>
+				<tr>
+					<td>
+						<?php print __('Search');?>
+					</td>
+					<td>
+						<input id='filter' type='text' size='25' value='<?php print html_escape_request_var('filter');?>'>
+					</td>
 					<td>
 						<?php print __('Rows');?>
 					</td>
@@ -1381,10 +1428,8 @@ function utilities_view_snmp_cache() {
 						</select>
 					</td>
 					<td>
-						<span>
-							<input type='submit' id='refresh' value='<?php print __esc_x('Button: use filter settings', 'Go');?>' title='<?php print __esc('Set/Refresh Filters');?>'>
-							<input type='button' id='clear' value='<?php print __esc_x('Button: reset filter settings', 'Clear');?>' title='<?php print __esc('Clear Filters');?>'>
-						</span>
+						<input id='with_index' type='checkbox' onChange='applyFilter()' title='<?php print __esc('Allow the search term to include the index column');?>' <?php if (get_request_var('with_index') == 1) { print ' checked '; }?>>
+						<label for='with_index'><?php print __('Include Index') ?></label>
 					</td>
 				</tr>
 			</table>
@@ -1420,7 +1465,11 @@ function utilities_view_snmp_cache() {
 			OR sq.name LIKE '%" . get_request_var('filter') . "%'
 			OR hsc.field_name LIKE '%" . get_request_var('filter') . "%'
 			OR hsc.field_value LIKE '%" . get_request_var('filter') . "%'
-			OR hsc.oid LIKE '%" . get_request_var('filter') . "%')";
+			OR hsc.oid LIKE '%" . get_request_var('filter') . "%'";
+		if (get_request_var('with_index') == 1) {
+			$sql_where .= " OR hsc.snmp_index LIKE '%" . get_request_var('filter') . "%'";
+		}
+		$sql_where .= ")";
 	}
 
 	$total_rows = db_fetch_cell("SELECT COUNT(*)
@@ -1909,17 +1958,17 @@ function boost_display_run_status() {
 
 	load_current_session_value('refresh', 'sess_boost_utilities_refresh', '30');
 
-	$last_run_time   = read_config_option('boost_last_run_time', TRUE);
-	$next_run_time   = read_config_option('boost_next_run_time', TRUE);
+	$last_run_time   = read_config_option('boost_last_run_time', true);
+	$next_run_time   = read_config_option('boost_next_run_time', true);
 
-	$rrd_updates     = read_config_option('boost_rrd_update_enable', TRUE);
-	$boost_cache     = read_config_option('boost_png_cache_enable', TRUE);
+	$rrd_updates     = read_config_option('boost_rrd_update_enable', true);
+	$boost_cache     = read_config_option('boost_png_cache_enable', true);
 
-	$max_records     = read_config_option('boost_rrd_update_max_records', TRUE);
-	$max_runtime     = read_config_option('boost_rrd_update_max_runtime', TRUE);
-	$update_interval = read_config_option('boost_rrd_update_interval', TRUE);
-	$peak_memory     = read_config_option('boost_peak_memory', TRUE);
-	$detail_stats    = read_config_option('stats_detail_boost', TRUE);
+	$max_records     = read_config_option('boost_rrd_update_max_records', true);
+	$max_runtime     = read_config_option('boost_rrd_update_max_runtime', true);
+	$update_interval = read_config_option('boost_rrd_update_interval', true);
+	$peak_memory     = read_config_option('boost_peak_memory', true);
+	$detail_stats    = read_config_option('stats_detail_boost', true);
 
 	$refresh['seconds'] = get_request_var('refresh');
 	$refresh['page']    = 'utilities.php?action=view_boost_status&header=false';
@@ -1995,7 +2044,7 @@ function boost_display_run_status() {
 
 	$total_data_sources = db_fetch_cell('SELECT COUNT(*) FROM poller_item');
 
-	$boost_status = read_config_option('boost_poller_status', TRUE);
+	$boost_status = read_config_option('boost_poller_status', true);
 	if ($boost_status != '') {
 		$boost_status_array = explode(':', $boost_status);
 
@@ -2011,7 +2060,7 @@ function boost_display_run_status() {
 		$boost_status_date = '';
 	}
 
-	$stats_boost = read_config_option('stats_boost', TRUE);
+	$stats_boost = read_config_option('stats_boost', true);
 	if ($stats_boost != '') {
 		$stats_boost_array = explode(' ', $stats_boost);
 
@@ -2026,13 +2075,13 @@ function boost_display_run_status() {
 	}
 
 	/* get cache directory size/contents */
-	$cache_directory    = read_config_option('boost_png_cache_directory', TRUE);
+	$cache_directory    = read_config_option('boost_png_cache_directory', true);
 	$directory_contents = array();
 
 	if (is_dir($cache_directory)) {
 		if ($handle = @opendir($cache_directory)) {
 			/* This is the correct way to loop over the directory. */
-			while (FALSE !== ($file = readdir($handle))) {
+			while (false !== ($file = readdir($handle))) {
 				$directory_contents[] = $file;
 			}
 
@@ -2110,12 +2159,12 @@ function boost_display_run_status() {
 	if ($output_length != '') {
 		$parts = explode(':', $output_length);
 		if ((time()-1200) > $parts[0]) {
-			$ref = TRUE;
+			$ref = true;
 		} else {
-			$ref = FALSE;
+			$ref = false;
 		}
 	} else {
-		$ref = TRUE;
+		$ref = true;
 	}
 
 	if ($ref) {
@@ -2208,7 +2257,7 @@ function boost_display_run_status() {
 	form_alternate_row();
 	print '<td>' . __('Cached Files Size:') . '</td><td>' . $directory_size . '</td>';
 
-	html_end_box(TRUE);
+	html_end_box(true);
 }
 
 /**
